from django.db.backends.mysql.base import DatabaseWrapper as MysqlDatabaseWrapper
from .features import DatabaseFeatures

class DatabaseWrapper(MysqlDatabaseWrapper):
    vendor = 'vitess'

    def __init__(self, *args, **kwargs):
        super(DatabaseWrapper, self).__init__(*args, **kwargs)
        self.features = DatabaseFeatures(self)



from django.db.backends.mysql.features import DatabaseFeatures as MysqlBaseDatabaseFeatures

class DatabaseFeatures(MysqlBaseDatabaseFeatures):
    supports_transactions = False
    uses_savepoints = False
    supports_foreign_keys = False



from setuptools import find_packages, setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="django-vitess",
    version="0.0.1",
    description="Custom database driver for Vitess.io",
    long_description=long_description,
    author="Babis Kaidos",
    author_email="ckaidos@intracom-telecom.com",
    url="https://github.com/BabisK/django-vitess",
    packages=find_packages(),
    install_requires=[
        "Django>=2.2"
    ],
    license="Apache Software License",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Framework :: Django :: 2.2",
        "Framework :: Django :: 3.0",
        "Framework :: Django :: 3.1",
        "Framework :: Django :: 3.2",
        "Intended Audience :: Developers",
        "Intended Audience :: Information Technology",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Topic :: Database"
    ]
)
